import os
import re

def find_rundirs_folders(root_path):
    rundir_folders = []

    for dirpath, _, filenames in os.walk(root_path):
        if "time.step" in filenames:
            rundir_folders.append(dirpath)

    return rundir_folders

def get_timesteps(rundir):
    try:
        with open(os.path.join(rundir, 'time.step')) as file:
            lines = file.readlines()
            if lines: return lines[-1].strip()
            else: return None
    except Exception as e:
        print(e)
        return None

def get_execution_time(rundir):
    try:
        with open(os.path.join(rundir, 'timing.output')) as file:
            b_found=False
            for line in file.readlines():
                if "Elapsed Time (s)  CPU Time (s)" in line:
                    b_found=True
                elif b_found:
                    elap_time, cpu_time = line.strip().split()
                    return elap_time, cpu_time
            return None, None
    except Exception as e:
        print(e)
        return None, None

def get_timestep_timings(rundir, total_ts):
    ts_time_dict = {}
    pattern = re.compile(r'timing step\s+(\d+)\s+:\s+([\d\.]+)')
    try:
        with open(os.path.join(rundir, 'timing.output')) as file:

            for line in file.readlines():
                match = pattern.search(line)
                if match:
                    step = int(match.group(1))
                    time = float(match.group(2))
                    ts_time_dict[step] = time

    except Exception as e:
        print(e)
        return None


    return ts_time_dict
